==> gnome-builder-3.16.0.tar.xz: gnome-builder-3.16.0/src/app/gb-application-credits.h <==
/* gb-application-credits.h
 *
 * Copyright (C) 2015 Christian Hergert <christian@hergert.me>
 *
 * This file is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This file is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef GB_APPLICATION_CREDITS_H
#define GB_APPLICATION_CREDITS_H

#include <glib.h>

G_BEGIN_DECLS

static const gchar *gb_application_credits_artists[] = {
  "Allan Day",
  "Hylke Bons",
  "Jakub Steiner",
  NULL
};

static const gchar *gb_application_credits_authors[] = {
  "Alexander Larsson",
  "Alexandre Franke",
  "Carlos Soriano",
  "Christian Hergert",
  "Cosimo Cecchi",
  "Dimitris Zenios",
  "Fabiano Fidêncio",
  "Florian Bäuerle",
  "Florian Müllner",
  "Hashem Nasarat",
  "Hylke Bons",
  "Igor Gnatenko",
  "Jakub Steiner",
  "Jasper St. Pierre",
  "Jonathon Jongsma",
  "Mathieu Bridon",
  "Megh Parikh",
  "Michael Catanzaro",
  "Pete Travis",
  "Ray Strode",
  "Roberto Majadas",
  "Ting-Wei Lan",
  "Trinh Anh Ngoc",
  "Yosef Or Boczko",
  NULL
};

static const gchar *gb_application_credits_documenters[] = {
  NULL
};

static const gchar *gb_application_credits_funders[] = {
  "Aaron Hergert",
  "Abdul Kadri Gündoğdu",
  "Abimael Martinez Carrete",
  "Adam grunden",
  "Adrian Bradshaw",
  "Adrian Rocha",
  "Adrià Arrufat",
  "Alaska Subedi",
  "Alessandro Bono",
  "Alexander Khatsayuk",
  "Alexander Larsson",
  "Alexander Murray",
  "Alexandre Franke",
  "Alexandros Diavatis",
  "Alfonso de Cala Bravo",
  "Alfred Santacatalina Gea",
  "Andreas Nilsson",
  "Andrew Stiegmann",
  "Andrew Walton",
  "Anton Shafarenko",
  "Aram J Agajanian",
  "Arturo Buentello G",
  "Arun Raghavan",
  "Aurélien Naldi",
  "Baldessari Michele",
  "Bastian Ilsø Hougaard",
  "Bastien Nocera",
  "Benjamin Grimm-Lebsanft",
  "Bernd Homuth",
  "Brad Taylor",
  "Brendan Long",
  "Bruce Cowan",
  "Canek Pelaez Valdes",
  "Carlos Soriano Sanchez",
  "Casey E Megginson",
  "Cedric Briner",
  "Centricular Ltd",
  "Cheng-Chia Tseng",
  "Christian Hergert",
  "Christopher Brian Sherlock",
  "Christopher Horton",
  "Christopher Kim",
  "Christopher William Bell",
  "Chun-Sheng Wu",
  "Cody Russell",
  "Cosimo Cecchi",
  "Craig A Cabrey",
  "Dag Robøle",
  "Daiki Ueno",
  "Daniel Buch",
  "Daniel Dui",
  "Daniel Espinosa Ortiz",
  "Daniel Nemec",
  "Daniel Pfeifer",
  "Danilo Gropelo",
  "Danylo Korostil",
  "Debarshi Ray",
  "Demetris Lambrou",
  "Denver Gingerich",
  "Dolgoff ",
  "Eduardo Silva",
  "Eitan Isaacson",
  "Elad Alfassa",
  "Ellis Kenyo",
  "Emanuele Aina",
  "Emanuele Gissi",
  "Emmanuele Bassi",
  "Enrique Ocaña González",
  "Eric T Miller",
  "Erik Helin",
  "Ernest hershey",
  "Erwan BOUSSE",
  "F. Kooman",
  "Fabian Alexander Wilms",
  "Fabio Valentini",
  "Faizan Qazi",
  "Fasiello Nicomede",
  "Federico Mena Quintero",
  "Filipe Santos",
  "Florian Bäuerle",
  "Florian Schweikert",
  "Florin Florica",
  "Frank Hansen",
  "Fredrik Schaller",
  "G A Foster",
  "Garrett LeSage",
  "Georges Seguin",
  "Georges-Mickael Seguin",
  "Gil Forcada Codinachs",
  "Go Min YounG",
  "Gonzalo Paniagua Javier",
  "Guillaume Quintard",
  "Gustavo Arejano",
  "Gustavo N Silva",
  "Hain Guillaume",
  "Hannes Ovrén",
  "Hendrik Richter",
  "Henry Finucane",
  "I Martin Rodriguez",
  "Ian Bolf",
  "Ian McKellar",
  "Ignacio Casal Quinteiro",
  "Igor Gnatenko",
  "Ioram Gordadze",
  "Ivan Nezhdanov",
  "J. Pereira Rocha",
  "J.A.J. Vermeulen",
  "James M Cape",
  "James Mason",
  "Jan Dudulski",
  "Jason Carey",
  "Jason D Levine",
  "Jason R Anderson",
  "Jean-François Fortin Tam",
  "Jeff Waugh",
  "Jeffrey Dorrycott",
  "Jesse van den Kieboom",
  "Jim Campbell",
  "Joaquin Mendez",
  "Johan Dahlin",
  "John Gary Billings",
  "John M Carr",
  "John Palmieri",
  "Jonathan Lane",
  "Jonathan Lestrelin",
  "Jonathan Zuñiga Juarez",
  "Jonathon Jongsma",
  "Jorge Rodriguez Flores Esp",
  "Joseph Hain",
  "Juan Jose Marin Martinez",
  "Julien Girardin",
  "Jussi Henrik Kukkonen",
  "Justin D Kruger",
  "Justyn Butler",
  "Keith Tokash",
  "Kenneth Nielsen",
  "Kris Thomsen",
  "Landwerlin ",
  "Lapo Calamandrei",
  "Lars Uebernickel",
  "Laurent Mouillart",
  "Le Guevel Gwendal",
  "Lucas Almeida ROcha",
  "Lukasz Ochoda",
  "Luke Gaudreau",
  "M. Aurélien Couderc",
  "Mac Baker",
  "Maciej M Piechotka",
  "Marc Andre Lureau",
  "Marc Thomas",
  "Marcio Sousa Rocha",
  "Marcus Husar",
  "Marcus Lundblad",
  "Marek Suchánek",
  "Marina Zhurakhinskaya",
  "Mario Sanchez-Prada",
  "Marius Mather",
  "Mart Roosmaa",
  "Martin A Stembel",
  "Martin Blanchard",
  "Martin Unzner",
  "Matej Smid",
  "Mattias Bengtsson",
  "Max Whittingham",
  "Maxim Yaskevich",
  "Michael Catanzaro",
  "Michael Grundy",
  "Michael Kuhn",
  "Michael Mansell",
  "Michael S DePaulo",
  "Michel Alexandre Salim",
  "Miguel e dos Santos",
  "Mikel Olasagasti Uranga",
  "Mikhail Feshchenko",
  "Molly Shelestak",
  "Nathan Samson",
  "Neil Stalker",
  "Neils Nesse",
  "Nelson Jesus Benitez Leon",
  "Nicholas E Richards",
  "Nicholas George",
  "Nick Melnick",
  "Niclas Moeslund Overby",
  "Nicolas Jeker",
  "Niklas Rosenqvist",
  "Nikola Trifunovic",
  "Nil Gradisnik",
  "Nirbheek Chauhan",
  "Oliver Propst",
  "Olivier Crete",
  "Ondřej Holý",
  "Ondřej Tůma",
  "Owen Taylor",
  "P Tunnell Wilson",
  "P.F. Mulder",
  "Pacaud Emmanuel",
  "Pakkanen Jussi T",
  "Paolo Borelli",
  "Patrik Nilsson",
  "Paul R Martin",
  "Pedro J Ayala Gomariz",
  "Perry L Peters",
  "Peter Baumgarten",
  "Peter Cornelis",
  "Peter Weber",
  "Philip Corbett",
  "Philip F Chimento",
  "Philip J Freeman",
  "Philip Whitfield",
  "Piotr Zurek",
  "R A McQueen",
  "RM van Schouwen",
  "Radosław Sierbiński",
  "Ray Strode",
  "Remi Grolleau",
  "Rickard Johansson",
  "Robert Taylor",
  "Roberto Clapis",
  "Rory MacQueen",
  "Rosanna Blandford",
  "Ross N Gardiner",
  "Rouchon Jean-Noel",
  "Rui Paulo Barreira",
  "Russell Cox",
  "Ryan Hartlage",
  "Ryan Lerch",
  "Rémi Lauzier",
  "S Axon",
  "Sajid Badi-uz-zaman",
  "Samuel B Thursfield",
  "Samuel Gyger",
  "Sasan Namiranian",
  "Saul Vargas Sandoval",
  "Sebastian Droege",
  "Shapor Naghibzadeh",
  "Shawn Ferris",
  "Shlomo Choina",
  "Shuji Narazaki",
  "Simon Roesch",
  "Sriram Ramkrishna",
  "Stefi T Petit",
  "Stephen Genusa",
  "Stephen Shaw",
  "Steve Z McCauley",
  "Steven J Herber",
  "Steven W Brown",
  "Steven Wills",
  "Stuart Ellis",
  "Stéphane Démurget",
  "Søren Hauberg",
  "Ted Hennicke",
  "Thibault Saunier",
  "Thomas Andersen",
  "Thomas McDonald",
  "Tom Erik Gundersen",
  "Tomas Peterka",
  "Torsten Scholak",
  "Tyler J. Brock",
  "Uwe Hametner",
  "Vadzim Rutkouski",
  "WP Manley",
  "William J Thompson",
  "William Jon McCann",
  "William R Lachance",
  "Z Jedrzejewski-Szmek",
  NULL
};

G_END_DECLS

#endif /* GB_APPLICATION_CREDITS_H */

==> gnome-builder-3.18.0.tar.xz: gnome-builder-3.18.0/src/app/gb-application-credits.h <==
/* gb-application-credits.h
 *
 * Copyright (C) 2015 Christian Hergert <christian@hergert.me>
 *
 * This file is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This file is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef GB_APPLICATION_CREDITS_H
#define GB_APPLICATION_CREDITS_H

#include <glib.h>

G_BEGIN_DECLS

static const gchar *gb_application_credits_artists[] = {
  "Allan Day",
  "Hylke Bons",
  "Jakub Steiner",
  NULL
};

static const gchar *gb_application_credits_authors[] = {
  "Alexander Larsson",
  "Alexandre Franke",
  "Andika Triwidada",
  "Andreas Henriksson",
  "Antoine Jacoutot",
  "Aurimas Černius",
  "Baurzhan Muftakhidinov",
  "Ben Iofel",
  "Bernd Homuth",
  "burningTyger",
  "Carlos Garnacho",
  "Carlos Soriano",
  "Changwoo Ryu",
  "Chao-Hsiung Liao",
  "Cheng-Chia Tseng",
  "Christian Hergert",
  "Christian Kirbach",
  "Cosimo Cecchi",
  "Daniel Korostil",
  "Daniel Mustieles",
  "David King",
  "Dimitris Zenios",
  "Dušan Kazik",
  "Ekaterina Gerasimova",
  "Elad Alfassa",
  "Erick Pérez Castellanos",
  "Fabiano Fidêncio",
  "Florian Bäuerle",
  "Florian Müllner",
  "Fran Dieguez",
  "Gabor Kelemen",
  "Gábor Kelemen",
  "Garrett Regier",
  "Giovanni Campagna",
  "Hashem Nasarat",
  "Hylke Bons",
  "Ian Hernandez",
  "Ignacio Casal Quinteiro",
  "Igor Gnatenko",
  "Jakub Steiner",
  "Jasper St. Pierre",
  "Jonathon Jongsma",
  "Jordi Mas",
  "Kalev Lember",
  "Kjartan Maraas",
  "Kristjan SCHMIDT",
  "Lars Uebernickel",
  "Marek Černocký",
  "Matej Urbančič",
  "Mathieu Bridon",
  "Megh Parikh",
  "Michael Catanzaro",
  "Mohan R",
  "Muhammet Kara",
  "Paolo Borelli",
  "Patrick Griffis",
  "Pedro Albuquerque",
  "Pete Travis",
  "Piotr Drąg",
  "Ray Strode",
  "Roberto Majadas",
  "Samir Ribic",
  "Sébastien Lafargue",
  "Timm Bäder",
  "TingPing",
  "Ting-Wei Lan",
  "Tobias Schönberg",
  "Tom Tryfonidis",
  "Trinh Anh Ngoc",
  "Wolf Vollprecht",
  "yannick inizan",
  "Yosef Or Boczko",
  "zilla@hmt.im",
  "Мирослав Николић",
  NULL
};

static const gchar *gb_application_credits_documenters[] = {
  "Christian Hergert",
  NULL
};

static const gchar *gb_application_credits_funders[] = {
  "曾政嘉",
  "Aaron Hergert",
  "Abdul Kadri Gündoğdu",
  "Abimael Martinez Carrete",
  "Adam grunden",
  "Adrian Bradshaw",
  "Adrian Rocha",
  "Adrià Arrufat",
  "Alaska Subedi",
  "Albert Murciego Rico",
  "Alessandro Bono",
  "Alexander B Libby",
  "Alexander Gleason",
  "Alexander Khatsayuk",
  "Alexander Larsson",
  "Alexander Murray",
  "Alexander Murray",
  "Alexandre Amoedo",
  "Alexandre Franke",
  "Alexandros Diavatis",
  "Alfonso de Cala Bravo",
  "Alfred Santacatalina Gea",
  "Andreas Nilsson",
  "Andrew Stiegmann",
  "Andrew Walton",
  "Anthony Taranto",
  "Anton Shafarenko",
  "Aram J Agajanian",
  "Arne Hoch",
  "Arturo Buentello G",
  "Arun Raghavan",
  "Ashley Sommer",
  "Aurélien Naldi",
  "B. Mille-Mathias",
  "Baldessari Michele",
  "Bastian Ilsø Hougaard",
  "Bastien Nocera",
  "Bastien Nocera",
  "Benjamin Grimm-Lebsanft",
  "Bernd Homuth",
  "Bill Roth",
  "Brad Taylor",
  "Brendan Long",
  "Brijesh Kartha",
  "Bruce Cowan",
  "Bruce M Franklin",
  "Búza Géza",
  "Canek Pelaez Valdes",
  "Carlos Soriano Sanchez",
  "Casey E Megginson",
  "Cedric Briner",
  "Cees Meijer",
  "Centricular Ltd",
  "Chema Casanova",
  "Cheng-Chia Tseng",
  "Chris Bagwell",
  "Chris Kühl",
  "Chris Tonkinson",
  "Christian Hergert",
  "Christian Lange",
  "Christopher Brian Sherlock",
  "Christopher Horton",
  "Christopher Kim",
  "Christopher William Bell",
  "Chun-Sheng Wu",
  "Cody Russell",
  "Cosimo Cecchi",
  "Craig A Cabrey",
  "Dag Robøle",
  "Daiki Ueno",
  "Damián Nohales",
  "Daniel Buch",
  "Daniel Dui",
  "Daniel Espinosa Ortiz",
  "Daniel Menchaca",
  "Daniel Nemec",
  "Daniel Pfeifer",
  "Daniel Vazquez Rivera",
  "Danilo Gropelo",
  "Danylo Korostil",
  "Debarshi Ray",
  "Demetris Lambrou",
  "Dennis Schulmeister",
  "Denver Gingerich",
  "Dolgoff ",
  "Eduardo Silva",
  "Eitan Isaacson",
  "Elad Alfassa",
  "Ellis Kenyo",
  "Emanuele Aina",
  "Emanuele Gissi",
  "Emmanuele Bassi",
  "Enrique Ocaña González",
  "Eric Streit",
  "Eric T Miller",
  "Erik Helin",
  "Ernest hershey",
  "Erwan Bousse",
  "Erwan Georget",
  "F. Kooman",
  "Fabian Alexander Wilms",
  "Fabien Cortina",
  "Fabio Valentini",
  "Faizan Qazi",
  "Faron S Anslow",
  "Fasiello Nicomede",
  "Federico Mena Quintero",
  "Felix Schröter",
  "Filipe Santos",
  "Florian Bäuerle",
  "Florian Over",
  "Florian Schweikert",
  "Florin Florica",
  "Frank Hansen",
  "Fredrik Schaller",
  "G A Foster",
  "G A Foster",
  "Gabriel Rauter",
  "Garrett LeSage",
  "Georges Seguin",
  "Georges-Mickael Seguin",
  "Gianluigi Calcaterra",
  "Gil Forcada Codinachs",
  "Giovanni Forte",
  "Go Min YounG",
  "Gonzalo Paniagua Javier",
  "Gordon Martin",
  "Guilherme Rodrigues",
  "Guillaume Beaudin",
  "Guillaume Hain",
  "Guillaume Quintard",
  "Gustavo Arejano",
  "Gustavo N Silva",
  "Hain Guillaume",
  "Hannes Ovrén",
  "Harald Hoyer",
  "Havoc Pennington",
  "Hendrik Richter",
  "Henrique Almeida",
  "Henry Finucane",
  "I Martin Rodriguez",
  "Ian Bolf",
  "Ian McKellar",
  "Ignacio Casal Quinteiro",
  "Igor Gnatenko",
  "Ilya Novosyolov",
  "Ioram Gordadze",
  "Ivan Nezhdanov",
  "J. Pereira Rocha",
  "J.A.J. Vermeulen",
  "Jack Jennings",
  "James M Cape",
  "James Mason",
  "James",
  "Jan Dudulski",
  "Jan-Christoph Borchardt",
  "Jason Carey",
  "Jason D Levine",
  "Jason R Anderson",
  "Jason Scurtu",
  "Javier Jardón",
  "Javier Monteagudo",
  "Jean-François Fortin Tam",
  "Jeff Waugh",
  "Jeffrey Dorrycott",
  "Jesse van den Kieboom",
  "Jim Campbell",
  "Jiri Eischmann",
  "Joakim Söderlund",
  "Joaquin Mendez",
  "Johan Dahlin",
  "John Gary Billings",
  "John M Carr",
  "John Palmieri",
  "Jonathan Lane",
  "Jonathan Lestrelin",
  "Jonathan Zuñiga Juarez",
  "Jonathon Jongsma",
  "Jorge Rodriguez Flores Esp",
  "Joseph Hain",
  "Juan Jose Marin Martinez",
  "Jugoslav Gacas",
  "Julien Girardin",
  "Jussi Henrik Kukkonen",
  "Justin D Kruger",
  "Justin Roth",
  "Justyn Butler",
  "Katrin Leinweber",
  "Keith Tokash",
  "Kenneth Nielsen",
  "Khalid Eldehairy",
  "Kris Thomsen",
  "Landwerlin",
  "Lapo Calamandrei",
  "Lars Uebernickel",
  "Laurent Mouillart",
  "Le Guevel Gwendal",
  "Leif Gruenwoldt",
  "Logan VanCuren",
  "Lucas Almeida Rocha",
  "Lukasz Ochoda",
  "Luke Gaudreau",
  "M C V Crouch",
  "M. Aurélien Couderc",
  "Mac Baker",
  "Maciej M Piechotka",
  "Magnun Leno Silva",
  "Marc Andre Lureau",
  "Marc Thomas",
  "Marcio Sousa Rocha",
  "Marco Barisione",
  "Marcus Husar",
  "Marcus Lundblad",
  "Marek Suchánek",
  "Marina Zhurakhinskaya",
  "Mario Sanchez-Prada",
  "Marius Heidenreich",
  "Marius Mather",
  "Markus Berg",
  "Mart Roosmaa",
  "Martin A Stembel",
  "Martin Andersson",
  "Martin Blanchard",
  "Martin Unzner",
  "Matej Smid",
  "Mathieu Bridon",
  "Matthew Nicholson",
  "Mattias Bengtsson",
  "Max Whittingham",
  "Maxim Yaskevich",
  "Michael Catanzaro",
  "Michael Grundy",
  "Michael Hill",
  "Michael Ivanov",
  "Michael Kuhn",
  "Michael Mansell",
  "Michael S DePaulo",
  "Michael Scofield",
  "Michel Alexandre Salim",
  "Miguel e dos Santos",
  "Mikel Olasagasti Uranga",
  "Mikhail Feshchenko",
  "Molly Shelestak",
  "Nasser Alshammari",
  "Nathan Samson",
  "Neil Stalker",
  "Neils Nesse",
  "Nelson Jesus Benitez Leon",
  "Nicholas E Richards",
  "Nicholas George",
  "Nick Melnick",
  "Niclas Moeslund Overby",
  "Nicola Mazbar",
  "Nicolas Jeker",
  "Niklas Rosenqvist",
  "Nikola Trifunovic",
  "Nil Gradisnik",
  "Nirbheek Chauhan",
  "Olav Vitters",
  "Oliver Propst",
  "Olivier Crete",
  "Ondřej Holý",
  "Ondřej Tůma",
  "Owen Taylor",
  "P Tunnell Wilson",
  "P.F. Mulder",
  "Pacaud Emmanuel",
  "Pakkanen Jussi T",
  "Paolo Borelli",
  "Pascal Garber",
  "Patrick Griffis",
  "Patrick Wspanialy",
  "Patrik Nilsson",
  "Patrizio Bruno",
  "Paul R Martin",
  "Pedro J Ayala Gomariz",
  "Perry L Peters",
  "Peter Baumgarten",
  "Peter Cornelis",
  "Peter J Shinners",
  "Peter Weber",
  "Philip Corbett",
  "Philip F Chimento",
  "Philip J Freeman",
  "Philip Whitfield",
  "Piotr Zurek",
  "R A McQueen",
  "R A McQueen",
  "RM van Schouwen",
  "Radosław Sierbiński",
  "Ray Strode",
  "Remco Kranenburg",
  "Remi Grolleau",
  "Rickard Johansson",
  "Robert Carr",
  "Robert Taylor",
  "Roberto Clapis",
  "Rodolphe PP",
  "Rory MacQueen",
  "Rosanna Blandford",
  "Ross N Gardiner",
  "Rouchon Jean-Noel",
  "Rui Paulo Barreira",
  "Russell Cox",
  "Ryan Hartlage",
  "Ryan Lerch",
  "Rémi Lauzier",
  "S Axon",
  "Sajid Badi-uz-zaman",
  "Samuel B Thursfield",
  "Samuel Gyger",
  "Sasan Namiranian",
  "Saul Vargas Sandoval",
  "Sebastian Droege",
  "Shapor Naghibzadeh",
  "Shawn Ferris",
  "Shlomo Choina",
  "Shuji Narazaki",
  "Simon Roesch",
  "Sriram Ramkrishna",
  "Stefi T Petit",
  "Stephany Wilkes",
  "Stephen Genusa",
  "Stephen Shaw",
  "Steve Z McCauley",
  "Steven J Herber",
  "Steven W Brown",
  "Steven Wills",
  "Stewart Webb",
  "Stuart Ellis",
  "Stéphane Démurget",
  "Stéphane Maniaci",
  "Søren Hauberg",
  "Tadej Janež",
  "Ted Hennicke",
  "Thibault Saunier",
  "Thomas Andersen",
  "Thomas Maffia",
  "Thomas McDonald",
  "Tom Erik Gundersen",
  "Tomas Peterka",
  "Tommi Tauriainen",
  "Tomáš Krchňák",
  "Tomáš Popela",
  "Toni Willberg",
  "Torsten Scholak",
  "Travis Hartwell",
  "Tyler J. Brock",
  "Uwe Hametner",
  "Vadzim Rutkouski",
  "Valter Schütz",
  "WP MANLEY",
  "WP Manley",
  "Wee Weea",
  "Wesley Wiser",
  "Will Binns-Smith",
  "William Hoffmann",
  "William J Thompson",
  "William J Thompson",
  "William Jon McCann",
  "William R Lachance",
  "Z Jedrzejewski-Szmek",
  "adam820",
  "arclnx",
  "aurelien.busi",
  "carwyn",
  "d.westerik",
  "daniel.fontaine",
  "david odenwald",
  "dchristidis",
  "demirtas burakk",
  "eik.w1911",
  "eliasdorneles",
  "elken.tdos",
  "fafatheone",
  "florian.muellner",
  "gerald.b.nunn",
  "gyger",
  "ich",
  "ideasman42",
  "jimmac",
  "jnoel",
  "joannis.orlandos",
  "joaquin8mendez",
  "joel",
  "juanjomarin96",
  "kamilprusko",
  "kenneth",
  "kesmarag",
  "kevin",
  "kidoz",
  "kuba",
  "lovenemesis",
  "luke.a.morton",
  "madstitz",
  "marc.chocolat",
  "mariospr",
  "markpariente",
  "matthias.clasen",
  "maxlupo",
  "mcatanzaro",
  "muflone",
  "nils.werner",
  "otaylor",
  "pedroclg",
  "peterldev94",
  "pizzamartijn",
  "pseus7+indiegogo",
  "public228",
  "ray strode",
  "ross",
  "sandquist",
  "scottm2031",
  "sebastien lafargue",
  "sebastien.wilmet",
  "sfs",
  "slyon",
  "swalf",
  "sylvain.pasche",
  "tglman",
  "theo",
  "tommaso.visconti",
  "vamega",
  "verduler",
  "vperetokin",
  "w.vollprecht",
  NULL
};

G_END_DECLS

#endif /* GB_APPLICATION_CREDITS_H */
